@@ -453,5 +453,10 @@ class Client(Singleton):
             return backend.geturl(bucket_info)
         else:
             return entrypoint
+
+    async def cleanup_cloud(self):
+        for k, backend in self.backend_pools:
+            print('cleanup {} files'.format(k))
+            await backend.cleanup_old_files()
                     
                     
\ No newline at end of file
