@@ -49,6 +49,11 @@ class MQManager(Singleton):
             
     def publish(self, topic, message, multi=False):
         try:
+            if not self.producer.is_running:
+                self.producer.close()
+                time.sleep(0.5)
+                self._init()
+                
             if multi and isinstance(message, list):
                 message = list(map(self._encode_message, message))
             else:
