@@ -1,4 +1,5 @@
 import traceback
+from cv2 import trace
 import redis
 import time
 import threading
@@ -264,6 +265,15 @@ class XRedis(Singleton):
         conn = self._get_connection()
         return conn.zscore(z_name, key)
 
+    def close(self):
+        try:
+            conn = self._get_connection()
+            if conn is not None:
+                conn.close()
+        except Exception as e:
+            traceback.print_exc()
+        
+
 try:
     from redis import asyncio as coredis
 except:
